==> mhu-lib-core-3.2.9-sources.jar: de/mhus/lib/core/schedule/IntervalWithStartTimeJob.java <==
package de.mhus.lib.core.schedule;

import java.util.Observer;

import de.mhus.lib.core.MCast;
import de.mhus.lib.core.MDate;

/**
 * Executes the task every 'interval' milliseconds after execution finished.
 *
 * @author mikehummel
 * @version $Id: $Id
 * @since 3.2.9
 */
public class IntervalWithStartTimeJob extends SchedulerJob implements MutableSchedulerJob {

	private long interval;
	private long start;

	/**
	 * <p>Constructor for IntervalWithStartTimeJob.</p>
	 *
	 * @param start a long.
	 * @param interval a long.
	 * @param task a {@link java.util.Observer} object.
	 */
	public IntervalWithStartTimeJob(long start, long interval, Observer task) {
		super(task);
		this.start = start;
		this.interval = interval;
	}

	/** {@inheritDoc} */
	@Override
	public void doCaclulateNextExecution() {
		if (isDone())
			setNextExecutionTime(System.currentTimeMillis() + interval);
		else
			setNextExecutionTime(start);
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		return 
			IntervalWithStartTimeJob.class.getSimpleName() + "," + MDate.toIsoDateTime(start) + "," + interval;
	}

	/** {@inheritDoc} */
	@Override
	public void doReschedule(Scheduler queue, long time) {
		super.doReschedule(queue, time);
	}

	/** {@inheritDoc} */
	@Override
	public void setDone(boolean done) {
		super.setDone(done);
	}

	/** {@inheritDoc} */
	@Override
	public boolean doReconfigure(String config) {
		long l = MCast.tolong(config, -1);
		if (l > 0 ) {
			interval = l;
			return true;
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public void setScheduledTime(long scheduledTime) {
		super.setScheduledTime(scheduledTime);
	}

}

==> mhu-lib-core-6.3.0-sources.jar: de/mhus/lib/core/schedule/IntervalWithStartTimeJob.java <==
/**
 * Copyright 2018 Mike Hummel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.mhus.lib.core.schedule;

import de.mhus.lib.core.ITimerTask;
import de.mhus.lib.core.MCast;
import de.mhus.lib.core.MDate;

/**
 * Executes the task every 'interval' milliseconds after execution finished.
 * @author mikehummel
 *
 */
public class IntervalWithStartTimeJob extends SchedulerJob implements MutableSchedulerJob {

	private long interval;
	private long start;

	public IntervalWithStartTimeJob(long start, long interval, ITimerTask task) {
		super(task);
		this.start = start;
		this.interval = interval;
	}

	@Override
	public void doCaclulateNextExecution() {
		if (isDone())
			setNextExecutionTime(System.currentTimeMillis() + interval);
		else
			setNextExecutionTime(start);
	}

	@Override
	public String toString() {
		return 
			IntervalWithStartTimeJob.class.getSimpleName() + "," + MDate.toIsoDateTime(start) + "," + interval;
	}

	@Override
	public void doReschedule(Scheduler queue, long time) {
		super.doReschedule(queue, time);
	}

	@Override
	public void setDone(boolean done) {
		super.setDone(done);
	}

	@Override
	public boolean doReconfigure(String config) {
		long l = MCast.tolong(config, -1);
		if (l > 0 ) {
			interval = l;
			return true;
		}
		return false;
	}

	@Override
	public void setScheduledTime(long scheduledTime) {
		super.setScheduledTime(scheduledTime);
	}

}
